@@ -145,9 +145,13 @@ class Code:
         repo = warez.Repo(bare_repo, init=True, bare=True)
         repo.update_server_info()
         repo.config("http.receivepack", "true")
-        subprocess.run(["chgrp", "www-data", bare_repo, "-R"])
-        subprocess.run(["chmod", "g+w", bare_repo, "-R"])
-        warez.clone_repo(bare_repo, working_repo)  # TODO shallow?
+        warez.clone_repo(bare_repo, working_repo)  # TODO shallow clone?
+        post_receive_hook = bare_repo / "hooks/post-receive"
+        with post_receive_hook.open("w") as fp:
+            fp.write("git -C $PWD/../working --git-dir=.git pull --rebase")
+        subprocess.run(["chmod", "775", post_receive_hook])
+        subprocess.run(["chgrp", "www-data", bare_repo, working_repo, "-R"])
+        subprocess.run(["chmod", "g+w", bare_repo, working_repo, "-R"])
         return web.Created(app.view.project_created(project), f"/{project}")
 
 
